SplitPackage

Struct SplitPackage 

pub struct SplitPackage {
    pub pkgname: String,
    pub operator: Option<String>,
    pub version: Option<String>,
}
A Struct representing a package’s name, operator, and version.

Fields

pkgname: Stringoperator: Option<String>version: Option<String>

Implementations

Source

impl SplitPackage

pub fn new(pkg_string: &str) -> Self

Split a dependency into its name, equality operator, and version. Note that this function simply splits on the first operator (“<<”, “>=”, etc etc.) found - if you pass in more than one the returned ‘version’ field will contain the remaining operators. Versions are also not checked to see if they’re valid, if you need such behavior please check inside of your application.